options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'test-package.dat' lrecl=94 missover DSD DLM=' ' print;
input
  R0000100
  R0536300
  R0536401
  R0536402
  R1200500
  R1200501
  R1200600
  R1200601
  R1220600
  R1220700
  R1222500
  R1222600
  R1235800
  R1482600
  R2395200
  R3705700
  R3880400
  R3880500
  R5161200
  R5459500
  R5459600
  R6889500
  R6889501
  R6889502
  S2412400
  S2412500
  S2412900
  S2413000
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "PUBID - YTH ID CODE 1997";
  label R0536300 = "KEY!SEX (SYMBOL) 1997";
  label R0536401 = "KEY!BDATE M/Y (SYMBOL) 1997";
  label R0536402 = "KEY!BDATE M/Y (SYMBOL) 1997";
  label R1200500 = "CV_CHILD_BIRTH_DATE L1 1997";
  label R1200501 = "CV_CHILD_BIRTH_DATE L1 1997";
  label R1200600 = "CV_CHILD_BIRTH_DATE L2 1997";
  label R1200601 = "CV_CHILD_BIRTH_DATE L2 1997";
  label R1220600 = "CV_WKSWK_JOB_YR L1,80 1997";
  label R1220700 = "CV_WKSWK_JOB_YR L1,81 1997";
  label R1222500 = "CV_WKSWK_JOB_YR L2,80 1997";
  label R1222600 = "CV_WKSWK_JOB_YR L2,81 1997";
  label R1235800 = "CV_SAMPLE_TYPE 1997";
  label R1482600 = "KEY!RACE_ETHNICITY (SYMBOL) 1997";
  label R2395200 = "INT REM RS RACE 1998";
  label R3705700 = "INT REM RS RACE 1999";
  label R3880400 = "CV_CHILD_BIRTH_DATE L1 1999";
  label R3880500 = "CV_CHILD_BIRTH_DATE L2 1999";
  label R5161200 = "INT REM RS RACE 2000";
  label R5459500 = "CV_CHILD_BIRTH_DATE L1 2000";
  label R5459600 = "CV_CHILD_BIRTH_DATE L2 2000";
  label R6889500 = "INT REM RS RACE 2001";
  label R6889501 = "INT REM RS RACE 2001";
  label R6889502 = "INT REM RS RACE 2001";
  label S2412400 = "CHK WHO RCV FIN AID FROM L1,1,1 2003";
  label S2412500 = "CHK WHO RCV FIN AID FROM L1,1,2 2003";
  label S2412900 = "CHK WHO RCV FIN AID FROM L1,2,1 2003";
  label S2413000 = "CHK WHO RCV FIN AID FROM L1,2,2 2003";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarantee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'PUBID_1997'n
  R0536300 = 'KEY!SEX_1997'n
  R0536401 = 'KEY!BDATE_M_1997'n
  R0536402 = 'KEY!BDATE_Y_1997'n
  R1200500 = 'CV_CHILD_BIRTH_DATE.01_M_1997'n
  R1200501 = 'CV_CHILD_BIRTH_DATE.01_Y_1997'n
  R1200600 = 'CV_CHILD_BIRTH_DATE.02_M_1997'n
  R1200601 = 'CV_CHILD_BIRTH_DATE.02_Y_1997'n
  R1220600 = 'CV_WKSWK_JOB_YR.01.80_1997'n
  R1220700 = 'CV_WKSWK_JOB_YR.01.81_1997'n
  R1222500 = 'CV_WKSWK_JOB_YR.02.80_1997'n
  R1222600 = 'CV_WKSWK_JOB_YR.02.81_1997'n
  R1235800 = 'CV_SAMPLE_TYPE_1997'n
  R1482600 = 'KEY!RACE_ETHNICITY_1997'n
  R2395200 = 'YIR-520_1998'n
  R3705700 = 'YIR-520_1999'n
  R3880400 = 'CV_CHILD_BIRTH_DATE.01~M_1999'n
  R3880500 = 'CV_CHILD_BIRTH_DATE.02~M_1999'n
  R5161200 = 'YIR-520_2000'n
  R5459500 = 'CV_CHILD_BIRTH_DATE.01~M_2000'n
  R5459600 = 'CV_CHILD_BIRTH_DATE.02~M_2000'n
  R6889500 = 'YIR-520~000001_2001'n
  R6889501 = 'YIR-520~000002_2001'n
  R6889502 = 'YIR-520~000003_2001'n
  S2412400 = 'YSCH-24400.01.01.01_2003'n
  S2412500 = 'YSCH-24400.01.01.02_2003'n
  S2412900 = 'YSCH-24400.01.02.01_2003'n
  S2413000 = 'YSCH-24400.01.02.02_2003'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx0f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
;
value vx1f
  0='No Information'
  1='Male'
  2='Female'
;
value vx2f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx4f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx5f
  1980-1995='1980 TO 1995: 1980 to 1995'
  1996='1996'
  1997='1997'
  1998='1998'
  1999='1999'
;
value vx6f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx7f
  1980-1995='1980 TO 1995: 1980 to 1995'
  1996='1996'
  1997='1997'
  1998='1998'
  1999='1999'
;
value vx8f
  0='0: 0 Weeks'
  1-5='1 TO 5: 1-5 Weeks'
  6-10='6 TO 10: 6-10 Weeks'
  11-15='11 TO 15: 11-15 Weeks'
  16-20='16 TO 20: 16-20 Weeks'
  21-25='21 TO 25: 21-25 Weeks'
  26-30='26 TO 30: 26-30 Weeks'
  31-35='31 TO 35: 31-35 Weeks'
  36-40='36 TO 40: 36-40 Weeks'
  41-45='41 TO 45: 41-45 Weeks'
  46-50='46 TO 50: 46-50 Weeks'
  51-999='51 TO 999: 51+ Weeks'
;
value vx9f
  0='0: 0 Weeks'
  1-5='1 TO 5: 1-5 Weeks'
  6-10='6 TO 10: 6-10 Weeks'
  11-15='11 TO 15: 11-15 Weeks'
  16-20='16 TO 20: 16-20 Weeks'
  21-25='21 TO 25: 21-25 Weeks'
  26-30='26 TO 30: 26-30 Weeks'
  31-35='31 TO 35: 31-35 Weeks'
  36-40='36 TO 40: 36-40 Weeks'
  41-45='41 TO 45: 41-45 Weeks'
  46-50='46 TO 50: 46-50 Weeks'
  51-999='51 TO 999: 51+ Weeks'
;
value vx10f
  0='0: 0 Weeks'
  1-5='1 TO 5: 1-5 Weeks'
  6-10='6 TO 10: 6-10 Weeks'
  11-15='11 TO 15: 11-15 Weeks'
  16-20='16 TO 20: 16-20 Weeks'
  21-25='21 TO 25: 21-25 Weeks'
  26-30='26 TO 30: 26-30 Weeks'
  31-35='31 TO 35: 31-35 Weeks'
  36-40='36 TO 40: 36-40 Weeks'
  41-45='41 TO 45: 41-45 Weeks'
  46-50='46 TO 50: 46-50 Weeks'
  51-999='51 TO 999: 51+ Weeks'
;
value vx11f
  0='0: 0 Weeks'
  1-5='1 TO 5: 1-5 Weeks'
  6-10='6 TO 10: 6-10 Weeks'
  11-15='11 TO 15: 11-15 Weeks'
  16-20='16 TO 20: 16-20 Weeks'
  21-25='21 TO 25: 21-25 Weeks'
  26-30='26 TO 30: 26-30 Weeks'
  31-35='31 TO 35: 31-35 Weeks'
  36-40='36 TO 40: 36-40 Weeks'
  41-45='41 TO 45: 41-45 Weeks'
  46-50='46 TO 50: 46-50 Weeks'
  51-999='51 TO 999: 51+ Weeks'
;
value vx12f
  0='Oversample'
  1='Cross-sectional'
;
value vx13f
  1='Black'
  2='Hispanic'
  3='Mixed Race (Non-Hispanic)'
  4='Non-Black / Non-Hispanic'
;
value vx14f
  1='White'
  2='Black'
  3='Other'
;
value vx15f
  1='White'
  2='Black'
  3='Other'
;
value vx16f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx17f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx18f
  1='White'
  2='Black'
  3='Other'
;
value vx19f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx20f
  1='1: January'
  2='2: February'
  3='3: March'
  4='4: April'
  5='5: May'
  6='6: June'
  7='7: July'
  8='8: August'
  9='9: September'
  10='10: October'
  11='11: November'
  12='12: December'
;
value vx21f
  0='NOT SELECTED'
  1='White'
;
value vx22f
  0='NOT SELECTED'
  1-2='Black or African American'
;
value vx23f
  0='NOT SELECTED'
  1-3='Asian'
;
value vx24f
  0='0: 0  CONDITION DOES NOT APPLY'
  1='1: 1  CONDITION APPLIES'
;
value vx25f
  0='0: 0  CONDITION DOES NOT APPLY'
  1='1: 1  CONDITION APPLIES'
;
value vx26f
  0='0: 0  CONDITION DOES NOT APPLY'
  1='1: 1  CONDITION APPLIES'
;
value vx27f
  0='0: 0  CONDITION DOES NOT APPLY'
  1='1: 1  CONDITION APPLIES'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format R0000100 vx0f.;
  format R0536300 vx1f.;
  format R0536401 vx2f.;
  format R1200500 vx4f.;
  format R1200501 vx5f.;
  format R1200600 vx6f.;
  format R1200601 vx7f.;
  format R1220600 vx8f.;
  format R1220700 vx9f.;
  format R1222500 vx10f.;
  format R1222600 vx11f.;
  format R1235800 vx12f.;
  format R1482600 vx13f.;
  format R2395200 vx14f.;
  format R3705700 vx15f.;
  format R3880400 vx16f.;
  format R3880500 vx17f.;
  format R5161200 vx18f.;
  format R5459500 vx19f.;
  format R5459600 vx20f.;
  format R6889500 vx21f.;
  format R6889501 vx22f.;
  format R6889502 vx23f.;
  format S2412400 vx24f.;
  format S2412500 vx25f.;
  format S2412900 vx26f.;
  format S2413000 vx27f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format 'PUBID_1997'n vx0f.;
  format 'KEY!SEX_1997'n vx1f.;
  format 'KEY!BDATE_M_1997'n vx2f.;
  format 'CV_CHILD_BIRTH_DATE.01_M_1997'n vx4f.;
  format 'CV_CHILD_BIRTH_DATE.01_Y_1997'n vx5f.;
  format 'CV_CHILD_BIRTH_DATE.02_M_1997'n vx6f.;
  format 'CV_CHILD_BIRTH_DATE.02_Y_1997'n vx7f.;
  format 'CV_WKSWK_JOB_YR.01.80_1997'n vx8f.;
  format 'CV_WKSWK_JOB_YR.01.81_1997'n vx9f.;
  format 'CV_WKSWK_JOB_YR.02.80_1997'n vx10f.;
  format 'CV_WKSWK_JOB_YR.02.81_1997'n vx11f.;
  format 'CV_SAMPLE_TYPE_1997'n vx12f.;
  format 'KEY!RACE_ETHNICITY_1997'n vx13f.;
  format 'YIR-520_1998'n vx14f.;
  format 'YIR-520_1999'n vx15f.;
  format 'CV_CHILD_BIRTH_DATE.01~M_1999'n vx16f.;
  format 'CV_CHILD_BIRTH_DATE.02~M_1999'n vx17f.;
  format 'YIR-520_2000'n vx18f.;
  format 'CV_CHILD_BIRTH_DATE.01~M_2000'n vx19f.;
  format 'CV_CHILD_BIRTH_DATE.02~M_2000'n vx20f.;
  format 'YIR-520~000001_2001'n vx21f.;
  format 'YIR-520~000002_2001'n vx22f.;
  format 'YIR-520~000003_2001'n vx23f.;
  format 'YSCH-24400.01.01.01_2003'n vx24f.;
  format 'YSCH-24400.01.01.02_2003'n vx25f.;
  format 'YSCH-24400.01.02.01_2003'n vx26f.;
  format 'YSCH-24400.01.02.02_2003'n vx27f.;
run;
*/